/*
*******************************************************************
*	Copyright by WATCOM Systems Inc. 1991. All rights	  *
*	reserved. No part of this software may be reproduced	  *
*	in any form or by any means - graphic, electronic or	  *
*	mechanical, including photocopying, recording, taping	  *
*	or information storage and retrieval systems - except	  *
*	with the written permission of WATCOM Systems Inc.	  *
*******************************************************************

These are cover routines to access the trmem memory tracker for programs
that have no need of special considerations.

The assumptions that these routines make are:
    - memory alloction is done through malloc, free, realloc
    - error messages are printed to stderr using write
    - all trmem checks are performed (all flags are set on)
    - all memory allocation throught these routines uses the same memory tracker
	    (i.e. same memory handle)

To use these routines compile trmemcvr.c into your program WITH THE FOLLOWING
COMPILE OPTIONS:  /dTRMEM /of+

If you leave off these options trmemcvr will use malloc, free, and realloc
directly.

No special options are required for routines that call the routine in trmemcvr.

Modified	By		Reason
--------	--		------
28 June 91	S.Bosnick	created
*/

#ifndef TRMEMCVR_H_INCLUDED
#define TRMEMCVR_H_INCLUDED

#include <stddef.h>

/* open and close the tracker */
extern void	TRMemOpen( void );
extern void	TRMemRedirect( int );
extern void	TRMemClose( void );

/* change all calls to malloc, free, and realloc with calls to these */
extern void *	TRMemAlloc( size_t size );
extern void	TRMemFree( void * ptr );
extern void *	TRMemRealloc( void * ptr, size_t size );


/* the rest of these functions are only available if trmemcvr was compiled */
/* with the options memtioned above */

/* print the current and peak usage to stderr */
extern void	TRMemPrtUsage( void );

/* print a list of the currently used blocks */
extern unsigned	TRMemPrtList( void );

/* check that ptr is valid */
extern int	TRMemValidate( void * ptr );

/* check that the len locations starting at start are properly allocated */
extern int	TRMemChkRange( void * start, size_t len );

#endif
